pub enum Policy {
Random,
Expire,
}Expand description
Eviction policy used when all candidate positions are occupied and displacement cannot free a slot.
Variants
Random
Select a random candidate for eviction.
Expire
Prefer evicting the candidate with the nearest expiration time.